@@ -1,5 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2010 The Music Player Daemon Project
+ * (c) 2004-2017 The Music Player Daemon Project
  * Project homepage: http://musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,12 +22,24 @@
 
 #include "command.h"
 
-/** put the terminal in a sane mode and stop/suspend ncmpc */
-void
-sigstop(void);
+#ifdef HAVE_GETMOUSE
+#include "ncmpc_curses.h"
+#endif
+
+#include <stdbool.h>
 
 void begin_input_event(void);
 void end_input_event(void);
-int do_input_event(command_t cmd);
+
+/**
+ * @return false if the application shall quit
+ */
+bool
+do_input_event(command_t cmd);
+
+#ifdef HAVE_GETMOUSE
+void
+do_mouse_event(int x, int y, mmask_t bstate);
+#endif
 
 #endif /* NCMPC_H */
